@@ -1,6 +1,9 @@
+from .version import __version__
+
 import torch
 from memtorch.bh import *
 from memtorch.bh.nonideality import *
-from memtorch.mn import *
-from memtorch.utils import *
 from memtorch.map import *
+from memtorch.mn import *
+from memtorch.submodules import *
+from memtorch.utils import *
