@@ -1,34 +1,35 @@
+import numpy as np
+import torch
+import torch.functional as F
+import torch.nn as nn
+
 import memtorch
 from memtorch.utils import convert_range
-import torch
-import torch.nn as nn
-import torch.functional as F
-import numpy as np
 
 
 def naive_map(weight, r_on, r_off, scheme, p_l=None):
     """Method to naively map network parameters to memristive device conductances, using two crossbars to represent both positive and negative weights.
 
-        Parameters
-        ----------
-        weight : torch.Tensor
-            Weight tensor to map.
-        r_on : float
-            Low resistance state.
-        r_off : float
-            High resistance state.
-        scheme: memtorch.bh.crossbar.Scheme
-            Weight representation scheme.
-        p_l: float
-            If not None, the proportion of weights to retain.
+    Parameters
+    ----------
+    weight : torch.Tensor
+        Weight tensor to map.
+    r_on : float
+        Low resistance state.
+    r_off : float
+        High resistance state.
+    scheme: memtorch.bh.crossbar.Scheme
+        Weight representation scheme.
+    p_l: float
+        If not None, the proportion of weights to retain.
 
-        Returns
-        -------
-        torch.Tensor, torch.Tensor
-            Positive and negative crossbar weights.
+    Returns
+    -------
+    torch.Tensor, torch.Tensor
+        Positive and negative crossbar weights.
     """
     if p_l is not None:
-        assert p_l >= 0 and p_l <= 1, 'p_l must be None or between 0 and 1.'
+        assert p_l >= 0 and p_l <= 1, "p_l must be None or between 0 and 1."
         weight_max, _ = torch.sort(weight.clone().abs().flatten(), descending=True)
         weight_max = weight_max[int(p_l * (weight.numel() - 1))]
         weight_min = weight_max / (r_off / r_on)
@@ -52,4 +53,4 @@ def naive_map(weight, r_on, r_off, scheme, p_l=None):
         crossbar = convert_range(crossbar, weight_min, weight_max, 1 / r_off, 1 / r_on)
         return crossbar
     else:
-        raise('%s is not currently supported.' % scheme)
+        raise ("%s is not currently supported." % scheme)
